@@ -1,3 +1,5 @@
+#include <md5.h>
+
 #include "dirdef.h"
 #include "filename.h"
 #include "doxygen.h"
@@ -66,32 +68,42 @@ void DirDef::addFile(FileDef *fd)
   fd->setDirDef(this);
 }
 
-static QCString escapeDirName(const QCString &anchor)
+static QCString encodeDirName(const QCString &anchor)
 {
   QCString result;
-  int l = anchor.length(),i;
-  for (i=0;i<l;i++)
-  {
-    char c = anchor.at(i);
-    if ((c>='a' && c<='z') || (c>='A' && c<='Z') || (c>='0' && c<='9'))
-    {
-      result+=c;
-    }
-    else
-    {
-      static char hexStr[]="0123456789ABCDEF";
-      char escChar[]={ '_', 0, 0, 0 };
-      escChar[1]=hexStr[c>>4];
-      escChar[2]=hexStr[c&0xf];
-      result+=escChar;
-    }
-  }
-  return result;
+
+  // convert to md5 hash
+  uchar md5_sig[16];
+  QCString sigStr(33);
+  MD5Buffer((const unsigned char *)anchor.data(),anchor.length(),md5_sig);
+  MD5SigToString(md5_sig,sigStr.data(),33);
+  return sigStr;
+
+  // old algorithm
+
+//  int l = anchor.length(),i;
+//  for (i=0;i<l;i++)
+//  {
+//    char c = anchor.at(i);
+//    if ((c>='a' && c<='z') || (c>='A' && c<='Z') || (c>='0' && c<='9'))
+//    {
+//      result+=c;
+//    }
+//    else
+//    {
+//      static char hexStr[]="0123456789ABCDEF";
+//      char escChar[]={ '_', 0, 0, 0 };
+//      escChar[1]=hexStr[c>>4];
+//      escChar[2]=hexStr[c&0xf];
+//      result+=escChar;
+//    }
+//  }
+//  return result;
 }
 
 QCString DirDef::getOutputFileBase() const
 {
-  return "dir_"+escapeDirName(name());
+  return "dir_"+encodeDirName(name());
   //return QCString().sprintf("dir_%06d",m_dirCount);
 }
 
@@ -215,7 +227,13 @@ void DirDef::writeDocumentation(OutputList &ol)
       if (!dd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
         ol.startMemberDescription();
-        ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),FALSE,FALSE);
+        ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),
+            FALSE, // indexWords
+            FALSE, // isExample
+            0,     // exampleName
+            FALSE, // single line
+            TRUE   // link from index
+           );
         ol.endMemberDescription();
         ol.newParagraph();
       }
@@ -268,7 +286,13 @@ void DirDef::writeDocumentation(OutputList &ol)
       if (!fd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
         ol.startMemberDescription();
-        ol.parseDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),FALSE,FALSE);
+        ol.parseDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),
+            FALSE, // indexWords
+            FALSE, // isExample
+            0,     // exampleName
+            FALSE, // single line
+            TRUE   // link from index
+           );
         ol.endMemberDescription();
         ol.newParagraph();
       }
@@ -342,8 +366,12 @@ void DirDef::addUsesDependency(DirDef *dir,FileDef *srcFd,
                                FileDef *dstFd,bool inherited)
 {
   if (this==dir) return; // do not add self-dependencies
-  //printf("  > add dependency %s->%s due to %s\n",shortName().data(),
-  //    dir->shortName().data(),fd->name().data());
+  //static int count=0;
+  //printf("  %d add dependency %s->%s due to %s->%s\n",
+  //    count++,shortName().data(),
+  //    dir->shortName().data(),
+  //    srcFd->name().data(),
+  //    dstFd->name().data());
 
   // levels match => add direct dependency
   bool added=FALSE;
@@ -371,15 +399,18 @@ void DirDef::addUsesDependency(DirDef *dir,FileDef *srcFd,
     m_usedDirs->insert(dir->getOutputFileBase(),usedDir);
     added=TRUE;
   }
-  if (added && dir->parent())
+  if (added)
   {
-    // add relation to parent of used dir
-    addUsesDependency(dir->parent(),srcFd,dstFd,inherited);
-  }
-  if (parent())
-  {
-    // add relation for the parent of this dir as well
-    parent()->addUsesDependency(dir,srcFd,dstFd,TRUE);
+    if (dir->parent())
+    {
+      // add relation to parent of used dir
+      addUsesDependency(dir->parent(),srcFd,dstFd,inherited);
+    }
+    if (parent())
+    {
+      // add relation for the parent of this dir as well
+      parent()->addUsesDependency(dir,srcFd,dstFd,TRUE);
+    }
   }
 }
 
@@ -394,6 +425,7 @@ void DirDef::computeDependencies()
     FileDef *fd;
     for (fli.toFirst();(fd=fli.current());++fli) // foreach file in dir dd
     {
+      //printf("  File %s\n",fd->name().data());
       //printf("** dir=%s file=%s\n",shortName().data(),fd->name().data());
       QList<IncludeInfo> *ifl = fd->includeFileList();
       if (ifl)
@@ -403,12 +435,15 @@ void DirDef::computeDependencies()
         for (ifli.toFirst();(ii=ifli.current());++ifli) // foreach include file
         {
           //printf("  > %s\n",ii->includeName.data());
+          //printf("    #include %s\n",ii->includeName.data());
           if (ii->fileDef && ii->fileDef->isLinkable()) // linkable file
           {
             DirDef *usedDir = ii->fileDef->getDirDef();
             if (usedDir)
             {
               // add dependency: thisDir->usedDir
+              //static int count=0;
+              //printf("      %d: add dependency %s->%s\n",count++,name().data(),usedDir->name().data());
               addUsesDependency(usedDir,fd,ii->fileDef,FALSE);
             }
           } 
@@ -526,8 +561,8 @@ void DirDef::writeDepGraph(QTextStream &t)
       t << "  bgcolor=transparent;\n";
     }
     t << "  compound=true\n";
-    t << "  node [ fontsize=10, fontname=\"Helvetica\"];\n";
-    t << "  edge [ labelfontsize=9, labelfontname=\"Helvetica\"];\n";
+    t << "  node [ fontsize=10, fontname=\"FreeSans.ttf\"];\n";
+    t << "  edge [ labelfontsize=9, labelfontname=\"FreeSans.ttf\"];\n";
 
     QDict<DirDef> dirsInGraph(257);
     
@@ -537,7 +572,7 @@ void DirDef::writeDepGraph(QTextStream &t)
       t << "  subgraph cluster" << parent()->getOutputFileBase() << " {\n";
       t << "    graph [ bgcolor=\"#ddddee\", pencolor=\"black\", label=\"" 
         << parent()->shortName() 
-        << "\" fontname=\"Helvetica\", fontsize=10, URL=\"";
+        << "\" fontname=\"FreeSans.ttf\", fontsize=10, URL=\"";
       t << parent()->getOutputFileBase() << Doxygen::htmlFileExtension;
       t << "\"]\n";
     }
@@ -806,6 +841,7 @@ void computeDirDependencies()
   // compute uses dependencies between directories
   for (sdi.toFirst();(dir=sdi.current());++sdi)
   {
+    //printf("computeDependencies for %s: #dirs=%d\n",dir->name().data(),Doxygen::directories.count());
     dir->computeDependencies();
   }
 
@@ -872,7 +908,7 @@ void writeDirDependencyGraph(const char *dirName)
       
       //QCString dotArgs(4096);
       //dotArgs.sprintf("%s -Tgif -o %s",path.data(),outFile.data());
-      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
+      //if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs,FALSE)!=0)
       //{
       //  err("Problems running dot. Check your installation!\n");
       //}
