@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.cpp,v 1.17 1998/11/28 11:33:19 root Exp $
  *
- * Copyright (C) 1997-2003 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -35,10 +35,9 @@ static QCString getExtension()
 {
   QCString ext = Config_getString("MAN_EXTENSION");
   if( ext.length() >= 2 &&
-      ext.data()[0] == '.' &&
-      isdigit( ext.data()[1] ) )
+      ext.data()[0] == '.')
   {
-    ext = ext.mid(1, 1);
+    ext = ext.mid(1, ext.length()-1);
   }
   else
   {
@@ -95,6 +94,7 @@ void ManGenerator::init()
     err("Could not create output directory %s/man%s\n",manOutput.data(),ext.data());
     exit(1);
   }
+  createSubDirs(d);
 }
 
 static QCString buildFileName(const char *name)
@@ -153,6 +153,8 @@ void ManGenerator::endTitleHead(const char *,const char *name)
 {
   t << ".TH \"" << name << "\" " << getExtension() << " \"" 
     << dateToString(FALSE) << "\" \"";
+  if (!Config_getString("PROJECT_NUMBER").isEmpty())
+    t << "Version " << Config_getString("PROJECT_NUMBER") << "\" \"";
   if (Config_getString("PROJECT_NAME").isEmpty()) 
     t << "Doxygen";
   else
@@ -370,7 +372,8 @@ void ManGenerator::startMemberDoc(const char *,const char *,const char *,const c
 }
 
 void ManGenerator::startDoxyAnchor(const char *,const char *manName,
-                                   const char *, const char *name)
+                                   const char *, const char *name,
+                                   const char *)
 {
     // something to be done?
     if( !Config_getBool("MAN_LINKS") ) 
@@ -403,7 +406,7 @@ void ManGenerator::startDoxyAnchor(const char *,const char *manName,
     linkfile.close();
 }
 
-void ManGenerator::endMemberDoc()
+void ManGenerator::endMemberDoc(bool)
 {
     t << "\"";
 }
@@ -624,11 +627,12 @@ void ManGenerator::endParamList()
 {
 }
 
-void ManGenerator::printDoc(DocNode *n)
+void ManGenerator::printDoc(DocNode *n,const char *langExt)
 {
-  ManDocVisitor *visitor = new ManDocVisitor(t,*this);
+  ManDocVisitor *visitor = new ManDocVisitor(t,*this,langExt);
   n->accept(visitor);
   delete visitor; 
   firstCol=FALSE;
+  paragraph = FALSE;
 }
 
