@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -24,7 +24,7 @@
 */
 #define CN_SPC
 
-class TranslatorChinese : public Translator
+class TranslatorChinese : public TranslatorAdapter_1_4_1
 {
   public:
 		/*! Used for identification of the language. The identification
@@ -83,9 +83,6 @@ class TranslatorChinese : public Translator
     virtual QCString trMemberEnumerationDocumentation()
     { return "Աöĵ"; }
 
-    virtual QCString trEnumerationValueDocumentation()
-    { return "Աöֵĵ"; }
-
 		/*! header that is put before the list of member function. */
     virtual QCString trMemberFunctionDocumentation()
     { return "Աĵ"; }
@@ -173,11 +170,6 @@ class TranslatorChinese : public Translator
     virtual QCString trFileList()
     { return "ļб"; }
 
-
-		/*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return "ͷļ"; }
-
 		/*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     { 
@@ -286,9 +278,6 @@ class TranslatorChinese : public Translator
       return result;
     }
 
-    virtual QCString trHeaderFilesDescription()
-    { return "гAPIͷļ"; }
-
     virtual QCString trExamplesDescription()
     { return "гʾ"; }
 
@@ -298,9 +287,6 @@ class TranslatorChinese : public Translator
     virtual QCString trModulesDescription()
     { return "гģ"; }
 
-    virtual QCString trNoDescriptionAvailable()
-    { return "޿ĵ"; }
-
     virtual QCString trDocumentation()
     { return "ĵ"; }
 
@@ -422,16 +408,9 @@ class TranslatorChinese : public Translator
  		virtual QCString trForInternalUseOnly()
     { return "ڲʹá"; }
 
- 		virtual QCString trReimplementedForInternalReasons()
-    { return "ڲԭأӰAPI"; 
-    }
-
  		virtual QCString trWarning()
     { return ""; }
 
- 		virtual QCString trBugsAndLimitations()
-    { return "BUG"CN_SPC""; }
-
  		virtual QCString trVersion()
     { return "汾"; }
 
@@ -698,12 +677,7 @@ class TranslatorChinese : public Translator
 // new since 0.49-991106
 //////////////////////////////////////////////////////////////////////////
 
- 		virtual QCString trSources()
-    {
-      return "Դ";
-    }
-
- 		virtual QCString trDefinedAtLineInSourceFile()
+                virtual QCString trDefinedAtLineInSourceFile()
     {
       return "ļ"CN_SPC"@1"CN_SPC""CN_SPC"@0"CN_SPC"ж塣";
     }
@@ -1025,12 +999,6 @@ class TranslatorChinese : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "ӿ";
-    }
-
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1068,12 +1036,6 @@ class TranslatorChinese : public Translator
       return "";
     }
 
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "ĵ";
-    }
-
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1228,20 +1190,6 @@ class TranslatorChinese : public Translator
 			return "Ա";
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool /*first_capital*/, bool /*singular*/)
-    { 
-			/*
-   		QCString result((first_capital ? "Field" : "field"));
-      if (!singular)  result+="s";
-      return result; 
-			*/
-			return "ֶ";
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1492,7 +1440,7 @@ class TranslatorChinese : public Translator
     virtual QCString trDirIndex()
     /*     { return "Directory Hierarchy"; } */
     {
-      return "$(BL\\¼$(DC((B";
+      return "Ŀ¼ṹ";
     }
 
     /*! This is used as the name of the chapter containing the documentation
@@ -1501,7 +1449,7 @@ class TranslatorChinese : public Translator
     virtual QCString trDirDocumentation()
     /*     { return "Directory Documentation"; } */
     {
-      return "$(BL\\¼J8[c(B";
+      return "Ŀ¼ĵ";
     }
 
     /*! This is used as the title of the directory index and also in the
@@ -1510,7 +1458,7 @@ class TranslatorChinese : public Translator
     virtual QCString trDirectories()
     /*     { return "Directories"; } */
     {
-      return "$(BL\\¼(B";
+      return "Ŀ¼";
     }
 
     /*! This returns a sentences that introduces the directory hierarchy. 
@@ -1521,7 +1469,7 @@ class TranslatorChinese : public Translator
 /*              "but not completely, alphabetically:"; */
 /*     } */
     {
-      return "$(BL\\¼$(DC($(BBgCWE*GSNs!$VuL$40A40D;zJl˳=x(B";
+      return "Ŀ¼ṹԵ";
     }
 
     /*! This returns the title of a directory page. The name of the
@@ -1531,7 +1479,7 @@ class TranslatorChinese : public Translator
     /*     { QCString result=dirName; result+=" Directory Reference"; return result; } */
     {
       QCString result=dirName;
-      result+=CN_SPC"$(BL\\¼;29M(B"; 
+      result+=CN_SPC"Ŀ¼ο"; 
       return result;
     }
 
@@ -1543,9 +1491,10 @@ class TranslatorChinese : public Translator
       /*       QCString result((first_capital ? "Director" : "director")); */
       /*       if (singular) result+="y"; else result+="ies"; */
       /*       return result;  */
-      return "$(BL\\¼(B";
+      return "Ŀ¼";
     }
     
 };
 
 #endif
+
